Rdocumentation
powered by
Learn R Programming
fitdistcp (version 0.2.3)
d080norm_p12_example_data_v1_t2: This is data to be included in my package
Description
This is data to be included in my package
Arguments