powered by
Densities from MLE and RHP
dexp_p1sub(x, t, y, t0)
A vector of parameter estimates, two pdf vectors, two cdf vectors
a vector of training data values
a vector or matrix of predictors
a vector of values at which to calculate the density and distribution functions
a single value of the predictor (specify either t0 or n0 but not both)
t0
n0