Learn R Programming

fitdistcp (version 0.2.3)

dgev_k3sub: Densities from MLE and RHP

Description

Densities from MLE and RHP

Usage

dgev_k3sub(x, y, kshape)

Value

A vector of parameter estimates, two pdf vectors, two cdf vectors

Arguments

x

a vector of training data values

y

a vector of values at which to calculate the density and distribution functions

kshape

the known shape parameter