Densities for 5 predictions
dgev_p1sub(x, t, y, t0, ics, minxi, maxxi, extramodels = FALSE)A vector of parameter estimates, two pdf vectors, two cdf vectors
a vector of training data values
a vector or matrix of predictors
a vector of values at which to calculate the density and distribution functions
a single value of the predictor (specify either t0 or n0 but not both)
initial conditions for the maximum likelihood search
minimum value of shape parameter xi
maximum value of shape parameter xi
logical that indicates whether to add three additional prediction models