Learn R Programming

fitdistcp (version 0.2.3)

dgpdsub: Densities for 5 predictions

Description

Densities for 5 predictions

Usage

dgpdsub(x, y, ics, kloc = 0, dlogpi = 0, minxi, maxxi, extramodels = FALSE)

Value

A vector of parameter estimates, two pdf vectors, two cdf vectors

Arguments

x

a vector of training data values

y

a vector of values at which to calculate the density and distribution functions

ics

initial conditions for the maximum likelihood search

kloc

the known location parameter

dlogpi

gradient of the log prior

minxi

minimum value of shape parameter xi

maxxi

maximum value of shape parameter xi

extramodels

logical that indicates whether to add three additional prediction models