Learn R Programming

fitdistcp (version 0.2.3)

dnorm_p12: Normal-with-p12: Density function

Description

Normal-with-p12: Density function

Usage

dnorm_p12(x, t01, t02, ymn, slope, sigma1, sigma2, log = FALSE)

Value

Vector

Arguments

x

a vector of training data values

t01

a single value of the predictor (specify either t01 or n01 but not both)

t02

a single value of the predictor (specify either t02 or n02 but not both)

ymn

the location parameter of the function of the predictor

slope

the slope of the function of the predictor

sigma1

first coefficient for the sigma parameter of the distribution

sigma2

second coefficient for the sigma parameter of the distribution

log

logical for the density evaluation