Learn R Programming

fitdistcp (version 0.2.3)

dnorm_p12dmgs: Densities for 5 predictions

Description

Densities for 5 predictions

Usage

dnorm_p12dmgs(x, t1, t2, y, t01, t02, ics)

Value

A vector of parameter estimates, two pdf vectors, two cdf vectors

Arguments

x

a vector of training data values

t1

a vector of predictors for the mean

t2

a vector of predictors for the sd

y

a vector of values at which to calculate the density and distribution functions

t01

a single value of the predictor (specify either t01 or n01 but not both)

t02

a single value of the predictor (specify either t02 or n02 but not both)

ics

initial conditions for the maximum likelihood search