Densities from MLE and RHP
dpareto_p1k2sub(x, t, y, t0, kscale, debug = FALSE)A vector of parameter estimates, two pdf vectors, two cdf vectors
a vector of training data values
a vector or matrix of predictors
a vector of values at which to calculate the density and distribution functions
a single value of the predictor (specify either t0 or n0 but not both)
the known scale parameter
debug flag