dweibull_p2sub: Densities from MLE and RHP
Description
Densities from MLE and RHP
Usage
dweibull_p2sub(x, t, y, t0)
Value
A vector of parameter estimates, two pdf vectors, two cdf vectors
Arguments
- x
a vector of training data values
- t
a vector or matrix of predictors
- y
a vector of values at which to calculate the density and distribution functions
- t0
a single value of the predictor (specify either t0 or n0 but not both)