Learn R Programming

fitdistcp (version 0.2.3)

exp_p1_mu2fa: Minus the second derivative of the cdf, at alpha

Description

Minus the second derivative of the cdf, at alpha

Usage

exp_p1_mu2fa(alpha, t0, v1, v2)

Value

Matrix

Arguments

alpha

a vector of values of alpha (one minus probability)

t0

a single value of the predictor (specify either t0 or n0 but not both)

v1

first parameter

v2

second parameter