Learn R Programming

fitdistcp (version 0.2.3)

gev_means: Analytical Expressions for Predictive Means RHP mean based on the expectation of DMGS equation 2.1

Description

Analytical Expressions for Predictive Means RHP mean based on the expectation of DMGS equation 2.1

Usage

gev_means(
  means,
  ml_params,
  lddi,
  lddd,
  lambdad_rh_flat,
  lambdad_custom,
  nx,
  dim = 3
)

Value

Two scalars

Arguments

means

logical that indicates whether to return analytical estimates for the distribution means (longer runtime)

ml_params

parameters

lddi

inverse observed information matrix

lddd

third derivative of log-likelihood

lambdad_rh_flat

derivative of the log CRHP-FLAT prior

lambdad_custom

custom value of the derivative of the log prior

nx

length of training data

dim

number of parameters