GEVD-with-p1: DMGS equation 1.2 f2 term
gev_p12_f2f(y, t01, t02, v1, d1, v2, d2, v3, d3, v4, d4, v5, d5)3d array
a vector of values at which to calculate the density and distribution functions
a single value of the predictor (specify either t01 or n01 but not both)
a single value of the predictor (specify either t02 or n02 but not both)
first parameter
the delta used in the numerical derivatives with respect to the parameter
second parameter
the delta used in the numerical derivatives with respect to the parameter
third parameter
the delta used in the numerical derivatives with respect to the parameter
fourth parameter
the delta used in the numerical derivatives with respect to the parameter
fifth parameter
the delta used in the numerical derivatives with respect to the parameter