Learn R Programming

fitdistcp (version 0.2.3)

gev_p1b_f2fa: The second derivative of the density for DMGS

Description

The second derivative of the density for DMGS

Usage

gev_p1b_f2fa(x, t0a, t0b, v1, v2, v3, v4, v5)

Value

Matrix

Arguments

x

a vector of training data values

t0a

a single value of the predictor, for the first column of the predictor (specify either t0a or n0a but not both)

t0b

a single value of the predictor, for the second column of the predictor (specify either t0b or n0b but not both)

v1

first parameter

v2

second parameter

v3

third parameter

v4

fourth parameter

v5

fifth parameter