Learn R Programming

fitdistcp (version 0.2.3)

gev_p1c_mu2fa: Minus the second derivative of the cdf, at alpha

Description

Minus the second derivative of the cdf, at alpha

Usage

gev_p1c_mu2fa(alpha, t0a, t0b, t0c, v1, v2, v3, v4, v5, v6)

Value

Matrix

Arguments

alpha

a vector of values of alpha (one minus probability)

t0a

a single value of the predictor, for the first column of the predictor (specify either t0a or n0a but not both)

t0b

a single value of the predictor, for the second column of the predictor (specify either t0b or n0b but not both)

t0c

a single value of the predictor, for the third column of the predictor (specify either t0c or n0c but not both)

v1

first parameter

v2

second parameter

v3

third parameter

v4

fourth parameter

v5

fifth parameter

v6

sixth parameter