Second derivative of the log density Created by Stephen Jewson using Deriv() by Andrew Clausen and Serguei Sokol
Second derivative of the log density Created by Stephen Jewson using Deriv() by Andrew Clausen and Serguei Sokol
halfnorm_logfdd(x, v1)halfnorm_logfdd(x, v1)
Matrix
Matrix
a vector of training data values
first parameter