Learn R Programming

fitdistcp (version 0.2.3)

ifvectorthenmatrix: If a variable is a vector, convert it to a matrix

Description

If a variable is a vector, convert it to a matrix

Usage

ifvectorthenmatrix(t)

Value

Vector

Arguments

t

a vector or matrix of predictors