Blank function I use for setting up the man page information for the functions
manf(
dim,
vv,
ml_params,
nx,
nxx,
x,
xx,
t,
nt,
ta,
tb,
tc,
t1,
t2,
t3,
tt,
tt1,
tt2,
tt3,
tt2d,
tt3d,
t0,
t0a,
t0b,
t0c,
t01,
t02,
t03,
t10,
t20,
t30,
n0,
n10,
n20,
p,
n,
y,
ics,
tresid,
tresid0,
muhat0,
vhat,
v1,
v1hat,
v1h,
d1,
fd1,
v2,
v2hat,
v2h,
d2,
fd2,
v3,
v3hat,
v3h,
d3,
fd3,
v4,
v4hat,
v4h,
d4,
fd4,
v5,
v5hat,
v5h,
d5,
v6,
v6hat,
v6h,
d6,
minxi,
maxxi,
ximin,
ximax,
fdalpha,
kscale,
kloc,
kshape,
kdf,
kbeta,
alpha,
ymn,
slope,
mu,
sigma,
sigma1,
sigma2,
scale,
shape,
xi,
xi1,
xi2,
lambda,
log,
mm,
nn,
rr,
lddi,
lddi_k2,
lddi_k3,
lddi_k4,
lddd,
lddd_k2,
lddd_k3,
lddd_k4,
lambdad,
lambdad_cp,
lambdad_rhp,
lambdad_flat,
lambdad_rh_mle,
lambdad_rh_flat,
lambdad_jp,
lambdad_custom,
means,
waicscores,
logscores,
extramodels,
pdf,
predictordata,
nonnegslopesonly,
rnonnegslopesonly,
customprior,
prior,
params,
yy,
pp,
dlogpi,
debug,
centering,
aderivs
)No return value
number of parameters
parameters
parameters
length of training data
length of training data
a vector of training data values
a vector of training data values
a vector or matrix of predictors
the number of columns in t
a vector of predictors for the mean (first column)
a vector of predictors for the mean (second column)
a vector of predictors for the mean (third column)
a vector of predictors for the mean
a vector of predictors for the sd
a vector of predictors for the shape
a vector of predictors
a vector of predictors for the mean
a vector of predictors for the sd
a vector of predictors for the shape
a matrix of predictors (nx by 2)
a matrix of predictors (nx by 3)
a single value of the predictor (specify either t0 or n0 but not both)
a single value of the predictor, for the first column of the predictor (specify either t0a or n0a but not both)
a single value of the predictor, for the second column of the predictor (specify either t0b or n0b but not both)
a single value of the predictor, for the third column of the predictor (specify either t0c or n0c but not both)
a single value of the predictor (specify either t01 or n01 but not both)
a single value of the predictor (specify either t02 or n02 but not both)
a single value of the predictor (specify either t03 or n03 but not both)
a single value of the predictor for the mean (specify either t10 or n10 but not both)
a single value of the predictor for the sd (specify either t20 or n20 but not both)
a single value of the predictor for the shape (specify either t30 or n30 but not both)
an index for the predictor (specify either t0 or n0 but not both)
an index for the predictor for the mean (specify either t10 or n10 but not both)
an index for the predictor for the sd (specify either t10 or n10 but not both)
a vector of probabilities at which to generate predictive quantiles
number of random samples required
a vector of values at which to calculate the density and distribution functions
initial conditions for the maximum likelihood search
predictor residuals
predictor residual at the point being predicted
muhat at the point being predicted
vector of all parameters
first parameter
first parameter
first parameter
the delta used in the numerical derivatives with respect to the parameter
the fractional delta used in the numerical derivatives with respect to the parameter
second parameter
second parameter
second parameter
the delta used in the numerical derivatives with respect to the parameter
the fractional delta used in the numerical derivatives with respect to the parameter
third parameter
third parameter
third parameter
the delta used in the numerical derivatives with respect to the parameter
the fractional delta used in the numerical derivatives with respect to the parameter
fourth parameter
fourth parameter
fourth parameter
the delta used in the numerical derivatives with respect to the parameter
the fractional delta used in the numerical derivatives with respect to the parameter
fifth parameter
fifth parameter
fifth parameter
the delta used in the numerical derivatives with respect to the parameter
sixth parameter
sixth parameter
sixth parameter
the delta used in the numerical derivatives with respect to the parameter
minimum value of shape parameter xi
maximum value of shape parameter xi
minimum value of shape parameter xi
maximum value of shape parameter xi
the fractional delta used in the numerical derivatives with respect to probability, for calculating the pdf as a function of quantiles
the known scale parameter
the known location parameter
the known shape parameter
the known degrees of freedom parameter
the known beta parameter
a vector of values of alpha (one minus probability)
the location parameter of the function of the predictor
the slope of the function of the predictor
the location parameter of the distribution
the sigma parameter of the distribution
first coefficient for the sigma parameter of the distribution
second coefficient for the sigma parameter of the distribution
the scale parameter of the distribution
the shape parameter of the distribution
the shape parameter of the distribution
first coefficient for the shape parameter of the distribution
second coefficient for the shape parameter of the distribution
the lambda parameter of the distribution
logical for the density evaluation
an index for which derivative to calculate
an index for which derivative to calculate
an index for which derivative to calculate
inverse observed information matrix
inverse observed information matrix, fixed shape parameter
inverse observed information matrix, fixed shape parameter
inverse observed information matrix, fixed shape parameter
third derivative of log-likelihood
third derivative of log-likelihood, fixed shape parameter
third derivative of log-likelihood, fixed shape parameter
third derivative of log-likelihood, fixed shape parameter
derivative of the log prior
derivative of the log prior
derivative of the log RHP prior
derivative of the log flat prior
derivative of the log CRHP-MLE prior
derivative of the log CRHP-FLAT prior
derivative of the log JP prior
custom value of the derivative of the log prior
logical that indicates whether to return analytical estimates for the distribution means (longer runtime)
logical that indicates whether to return estimates for the waic1 and waic2 scores (longer runtime)
logical that indicates whether to return leave-one-out estimates estimates of the log-score (much longer runtime)
logical that indicates whether to add three additional prediction models
logical that indicates whether to return density functions evaluated at quantiles specified by input probabilities
logical that indicates whether to calculate and return predictordata
logical that indicates whether to disallow non-negative slopes
logical that indicates whether to disallow non-negative slopes
a custom value for the slope of the log prior at the maxlik estimate
logical indicating which prior to use
model parameters for calculating logf
vector of samples
vector of probabilities
gradient of the log prior
debug flag
indicates whether the routine should center the data or not
logical for whether to use analytic derivatives (instead of numerical)