Learn R Programming

fitdistcp (version 0.2.3)

norm_p12_mu2fa: Minus the second derivative of the cdf, at alpha

Description

Minus the second derivative of the cdf, at alpha

Usage

norm_p12_mu2fa(alpha, t01, t02, v1, v2, v3, v4)

Value

Matrix

Arguments

alpha

a vector of values of alpha (one minus probability)

t01

a single value of the predictor (specify either t01 or n01 but not both)

t02

a single value of the predictor (specify either t02 or n02 but not both)

v1

first parameter

v2

second parameter

v3

third parameter

v4

fourth parameter