Learn R Programming

fitdistcp (version 0.2.3)

qnorm_p12: Normal-with-p12: Quantile function

Description

Normal-with-p12: Quantile function

Usage

qnorm_p12(p, t01, t02, ymn, slope, sigma1, sigma2)

Value

Vector

Arguments

p

a vector of probabilities at which to generate predictive quantiles

t01

a single value of the predictor (specify either t01 or n01 but not both)

t02

a single value of the predictor (specify either t02 or n02 but not both)

ymn

the location parameter of the function of the predictor

slope

the slope of the function of the predictor

sigma1

first coefficient for the sigma parameter of the distribution

sigma2

second coefficient for the sigma parameter of the distribution