weibull_p2_mu1fa: Minus the first derivative of the cdf, at alpha
Description
Minus the first derivative of the cdf, at alpha
Usage
weibull_p2_mu1fa(alpha, t0, v1, v2, v3)
Arguments
- alpha
a vector of values of alpha (one minus probability)
- t0
a single value of the predictor (specify either t0 or n0 but not both)
- v1
first parameter
- v2
second parameter
- v3
third parameter