powered by
Densities from MLE and RHP
dgev_k3sub(x, y, kshape)
A vector of parameter estimates, two pdf vectors, two cdf vectors
a vector of training data values
a vector of values at which to calculate the density and distribution functions
the known shape parameter