dgevsub: Densities for 5 predictions
Description
Densities for 5 predictions
Usage
dgevsub(x, y, ics, minxi, maxxi)
Value
A vector of parameter estimates, two pdf vectors, two cdf vectors
Arguments
- x
a vector of training data values
- y
a vector of values at which to calculate the density and distribution functions
- ics
initial conditions for the maximum likelihood search
- minxi
minimum value of shape parameter xi
- maxxi
maximum value of shape parameter xi