Densities for 5 predictions
dgpdsub(x, y, ics, kloc = 0, dlogpi = 0, minxi, maxxi, extramodels = FALSE)A vector of parameter estimates, two pdf vectors, two cdf vectors
a vector of training data values
a vector of values at which to calculate the density and distribution functions
initial conditions for the maximum likelihood search
the known location parameter
gradient of the log prior
minimum value of shape parameter xi
maximum value of shape parameter xi
logical that indicates whether to add three additional prediction models