Normal-with-p12: Density function
dnorm_p12(x, t01, t02, ymn, slope, sigma1, sigma2, log = FALSE)Vector
a vector of training data values
a single value of the predictor (specify either t01 or n01 but not both)
a single value of the predictor (specify either t02 or n02 but not both)
the location parameter of the function of the predictor
the slope of the function of the predictor
first coefficient for the sigma parameter of the distribution
second coefficient for the sigma parameter of the distribution
logical for the density evaluation