Densities for 5 predictions
dnorm_p12dmgs(x, t1, t2, y, t01, t02, ics)A vector of parameter estimates, two pdf vectors, two cdf vectors
a vector of training data values
a vector of predictors for the mean
a vector of predictors for the sd
a vector of values at which to calculate the density and distribution functions
a single value of the predictor (specify either t01 or n01 but not both)
a single value of the predictor (specify either t02 or n02 but not both)
initial conditions for the maximum likelihood search