Analytical Expressions for Predictive Means RHP mean based on the expectation of DMGS equation 2.1
gev_means(
means,
ml_params,
lddi,
lddd,
lambdad_rh_flat,
lambdad_custom,
nx,
dim = 3
)Two scalars
logical that indicates whether to return analytical estimates for the distribution means (longer runtime)
parameters
inverse observed information matrix
third derivative of log-likelihood
derivative of the log CRHP-FLAT prior
custom value of the derivative of the log prior
length of training data
number of parameters