The second derivative of the density for DMGS
gev_p1b_f2fa(x, t0a, t0b, v1, v2, v3, v4, v5)Matrix
a vector of training data values
a single value of the predictor, for the first column of the predictor (specify either t0a or n0a but not both)
a single value of the predictor, for the second column of the predictor (specify either t0b or n0b but not both)
first parameter
second parameter
third parameter
fourth parameter
fifth parameter