makebetat0: Calculate the location parameter when there are predictors (single time point)
Description
Calculate the location parameter when there are predictors (single time point)
Usage
makebetat0(nt, params, t0)
Arguments
- nt
the number of columns in t
- params
model parameters for calculating logf
- t0
a single value of the predictor (specify either t0 or n0 but not both)