makebetatm: Calculate the location parameter when there are predictors (multiple time points)
Description
Calculate the location parameter when there are predictors (multiple time points)
Usage
makebetatm(nt, params, t)
Arguments
- nt
the number of columns in t
- params
model parameters for calculating logf
- t
a vector or matrix of predictors